slack

package
v0.0.0-...-8155ea7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 2, 2026 License: GPL-2.0, GPL-3.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type SlackPlugin

type SlackPlugin struct{}

SlackPlugin implements ChannelPlugin interface for Slack

func (*SlackPlugin) ChannelPrefix

func (p *SlackPlugin) ChannelPrefix() string

ChannelPrefix returns the userId prefix this channel owns

func (*SlackPlugin) CreateChannel

func (p *SlackPlugin) CreateChannel(cfg *config.Config, bus *bus.MessageBus) (channels.Channel, error)

CreateChannel instantiates the channel implementation This calls the existing implementation from pkg/channels/slack

func (*SlackPlugin) Init

func (p *SlackPlugin) Init(ctx *plugin.RuntimeContext) error

Init initializes the plugin with runtime context

func (*SlackPlugin) IsEnabled

func (p *SlackPlugin) IsEnabled(cfg *config.Config) bool

IsEnabled checks if the channel is enabled in config

func (*SlackPlugin) Metadata

func (p *SlackPlugin) Metadata() plugin.Metadata

Metadata returns plugin metadata

func (*SlackPlugin) Validate

func (p *SlackPlugin) Validate(cfg *config.Config) error

Validate checks if the plugin can run with current config

Jump to